@@ -2,6 +2,7 @@ from django.urls import path
 from .views import (
     ApplicationViewSet,
     ApplicationDetailViewSet,
+    mark_as_doing,
     mark_as_done,
     mark_as_failed,
 )
@@ -17,6 +18,11 @@ urlpatterns = [
         ApplicationDetailViewSet.as_view({"get": "retrieve"}, lookup_field="slug"),
         name="ansible_inventory_detail",
     ),
+    path(
+        "ansible/<slug:slug>/doing/",
+        mark_as_doing,
+        name="ansible_inventory_mark_doing",
+    ),
     path(
         "ansible/<slug:slug>/done/",
         mark_as_done,
