@@ -1,4 +1,3 @@
-import uuid
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.db import models
@@ -6,10 +5,10 @@ from django.db.models.signals import pre_save, post_save
 from django.dispatch import receiver
 from django.utils.text import slugify
 from django.utils.translation import ugettext_lazy as _
+from djangoldp_component.models import Component, Package
 from djangoldp.models import Model
 from rest_framework.exceptions import ValidationError
-
-from djangoldp_component.models import Component, Package
+import uuid
 
 
 class Application(Model):
@@ -23,9 +22,13 @@ class Application(Model):
         null=True,
         blank=True,
     )
-    api_url = models.CharField(max_length=255, blank=True, null=True)
-    client_url = models.CharField(max_length=255, blank=True, null=True)
-    # May move appliation_* to graphics model?
+    api_url = models.CharField(
+        max_length=255, blank=True, null=True, help_text='Without "http(s)://"'
+    )
+    client_url = models.CharField(
+        max_length=255, blank=True, null=True, help_text='Without "http(s)://"'
+    )
+    # May move appliation_* to graphics?
     application_title = models.CharField(max_length=255, blank=True, null=True)
     application_logo = models.CharField(max_length=255, blank=True, null=True)
     slug = models.SlugField(unique=True, blank=True, null=True)
@@ -45,7 +48,7 @@ class Application(Model):
         authenticated_perms = ["inherit", "add"]
         auto_author = "creator"
         container_path = "/applications/"
-        depth = 1  # Do not serialize user
+        depth = 2  # Do not serialize user
         lookup_field = "slug"
         nested_fields = ["components", "packages"]
         ordering = ["slug"]
@@ -71,7 +74,9 @@ class Application(Model):
             "packages",
             "graphics",
             "services",
+            "npms",
             "federation",
+            "deployments",
         ]
         superuser_perms = ["view"]
         verbose_name = _("application")
@@ -80,6 +85,7 @@ class Application(Model):
 
 STATUS_CHOICES = [
     ("Todo", _("Todo")),
+    ("Doing", _("Doing")),
     ("Done", _("Done")),
     ("Failed", _("Failed")),
 ]
@@ -93,7 +99,15 @@ class Deployment(Model):
         null=True,
         blank=True,
     )
-    date = models.DateTimeField(auto_now_add=True)
+    requester = models.ForeignKey(
+        get_user_model(),
+        related_name="deployments",
+        on_delete=models.SET_NULL,
+        null=True,
+        blank=True,
+    )
+    date = models.DateTimeField(auto_now_add=True, verbose_name="Request date")
+    resolutionDate = models.DateTimeField(auto_now=True, verbose_name="Resolution date")
     status = models.CharField(
         max_length=8, choices=STATUS_CHOICES, default="Todo", null=True, blank=True
     )
@@ -111,18 +125,21 @@ class Deployment(Model):
         authenticated_perms = ["inherit", "add"]
         container_path = "/deployments/"
         depth = 0
-        ordering = ["application__urlid", "date"]
-        owner_field = "application__creator"
+        auto_author = "requester"
+        owner_field = "requester"
         owner_perms = ["inherit", "change", "delete"]
+        ordering = ["application__urlid", "date"]
         rdf_context = {
             "application": "sib:application",
             "date": "sib:deploymentDate",
+            "resolutionDate": "sib:deploymentDate",
             "status": "sib:deploymentStatus",
         }
         rdf_type = "sib:federation"
         serializer_fields = [
             "@id",
             "date",
+            "resolutionDate",
             "status",
         ]
         superuser_perms = ["view"]
@@ -197,7 +214,7 @@ class ApplicationGraphics(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-graphics/"
         owner_field = "application__creator"
         owner_perms = ["inherit", "change", "delete"]
@@ -236,7 +253,7 @@ class ApplicationService(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-services/"
         owner_field = "application__creator"
         owner_perms = ["inherit", "change", "delete"]
@@ -274,7 +291,7 @@ class ApplicationNPM(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-npms/"
         owner_field = "application__creator"
         owner_perms = ["inherit", "change", "delete"]
@@ -316,7 +333,7 @@ class ApplicationComponent(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-components/"
         nested_fields = ["component", "parameters"]
         owner_field = "application__creator"
@@ -366,7 +383,7 @@ class ApplicationComponentParameter(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-component-parameters/"
         owner_field = "component__application__creator"
         owner_perms = ["inherit", "change", "delete"]
@@ -408,7 +425,7 @@ class ApplicationPackage(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-packages/"
         nested_fields = ["package", "parameters"]
         owner_field = "application__creator"
@@ -458,7 +475,7 @@ class ApplicationPackageParameter(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "application-package-parameters/"
         owner_field = "package__application__creator"
         owner_perms = ["inherit", "change", "delete"]
@@ -502,7 +519,7 @@ class ComponentExtension(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "component-extensions/"
         nested_fields = ["component", "base_component"]
         owner_field = "base_component__application__creator"
@@ -552,7 +569,7 @@ class ComponentExtensionParameter(Model):
 
     class Meta(Model.Meta):
         anonymous_perms = ["view"]
-        authenticated_perms = ["inherit"]
+        authenticated_perms = ["inherit", "add"]
         container_path = "component-extension-parameters/"
         owner_field = "component__base_component__application__creator"
         owner_perms = ["inherit", "change", "delete"]
